@@ -1,8 +1,10 @@
-from typing import TYPE_CHECKING
+from typing import (
+    TYPE_CHECKING,
+    Any,
+)
 
 from .single_file import SingleFileSnapshotExtension
 
-
 if TYPE_CHECKING:
     from syrupy.types import SerializableData
 
@@ -18,5 +20,5 @@ class SVGImageSnapshotExtension(SingleFileSnapshotExtension):
     def _file_extension(self) -> str:
         return "svg"
 
-    def serialize(self, data: "SerializableData") -> bytes:
+    def serialize(self, data: "SerializableData", **kwargs: Any) -> bytes:
         return str(data).encode("utf-8")
