@@ -3,6 +3,7 @@ from gettext import gettext
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
+    Any,
     Optional,
     Set,
 )
@@ -14,13 +15,12 @@ from syrupy.data import (
 
 from .base import AbstractSyrupyExtension
 
-
 if TYPE_CHECKING:
-    from syrupy.types import SerializableData, SerializedData  # noqa: F401
+    from syrupy.types import SerializableData
 
 
 class SingleFileSnapshotExtension(AbstractSyrupyExtension):
-    def serialize(self, data: "SerializableData") -> bytes:
+    def serialize(self, data: "SerializableData", **kwargs: Any) -> bytes:
         return bytes(data)
 
     def get_snapshot_name(self, *, index: int = 0) -> str:
