@@ -7,7 +7,6 @@ from syrupy.extensions.image import (
     SVGImageSnapshotExtension,
 )
 
-
 actual_png = base64.b64decode(
     b"iVBORw0KGgoAAAANSUhEUgAAADIAAAAyBAMAAADsEZWCAAAAG1BMVEXMzMy"
     b"Wlpaqqqq3t7exsbGcnJy+vr6jo6PFxcUFpPI/AAAACXBIWXMAAA7EAAAOxA"
@@ -50,7 +49,7 @@ def test_multiple_snapshot_extensions(snapshot):
     These should be indexed in order of assertion.
     """
     assert actual_svg == snapshot(extension_class=SVGImageSnapshotExtension)
-    assert actual_svg == snapshot  # uses initial extension class
+    assert actual_svg == snapshot()  # uses initial extension class
     assert snapshot._extension is not None
     assert actual_png == snapshot(extension_class=PNGImageSnapshotExtension)
     assert actual_svg == snapshot(extension_class=SVGImageSnapshotExtension)
